[Libreoffice-commits] core.git: cui/source extensions/source filter/source fpicker/source include/svtools include/svx sc/source sfx2/inc sfx2/source svtools/source svx/source

Caolán McNamara (via logerrit) logerrit at kemper.freedesktop.org
Fri Feb 7 15:03:54 UTC 2020


 cui/source/dialogs/hltpbase.cxx                      |    2 
 cui/source/inc/hltpbase.hxx                          |    2 
 cui/source/options/doclinkdialog.cxx                 |    2 
 cui/source/options/doclinkdialog.hxx                 |    2 
 extensions/source/abpilot/abpfinalpage.cxx           |    2 
 extensions/source/abpilot/abpfinalpage.hxx           |    2 
 extensions/source/propctrlr/formcomponenthandler.cxx |    2 
 extensions/source/propctrlr/usercontrol.cxx          |    2 
 extensions/source/propctrlr/usercontrol.hxx          |    4 -
 filter/source/xsltdialog/xmlfiltertabpagexslt.cxx    |   12 +--
 filter/source/xsltdialog/xmlfiltertabpagexslt.hxx    |   10 +-
 fpicker/source/office/iodlg.cxx                      |    6 -
 fpicker/source/office/iodlg.hxx                      |    2 
 fpicker/source/office/iodlgimp.hxx                   |    6 -
 include/svtools/inettbc.hxx                          |   11 +-
 include/svx/databaselocationinput.hxx                |    6 -
 include/svx/imapdlg.hxx                              |    4 -
 sc/source/ui/inc/datastreamdlg.hxx                   |    4 -
 sc/source/ui/inc/linkarea.hxx                        |    4 -
 sc/source/ui/miscdlgs/datastreamdlg.cxx              |    2 
 sc/source/ui/miscdlgs/linkarea.cxx                   |    2 
 sfx2/inc/inettbc.hxx                                 |    4 -
 sfx2/source/inet/inettbc.cxx                         |   18 ++--
 svtools/source/control/inettbc.cxx                   |   76 +++++++++----------
 svx/source/dialog/imapdlg.cxx                        |    2 
 svx/source/form/databaselocationinput.cxx            |    8 +-
 svx/source/form/datanavi.cxx                         |    2 
 svx/source/inc/datanavi.hxx                          |    2 
 28 files changed, 99 insertions(+), 102 deletions(-)

New commits:
commit efa883f0585b0824091c1383ab318c671f83cd28
Author:     Caolán McNamara <caolanm at redhat.com>
AuthorDate: Fri Feb 7 12:12:58 2020 +0000
Commit:     Caolán McNamara <caolanm at redhat.com>
CommitDate: Fri Feb 7 16:03:10 2020 +0100

    rename URLBox back to SvtURLBox
    
    Change-Id: Icd90eeb492002c45ddd8ff562a6da411abead122
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/88185
    Tested-by: Jenkins
    Reviewed-by: Caolán McNamara <caolanm at redhat.com>

diff --git a/cui/source/dialogs/hltpbase.cxx b/cui/source/dialogs/hltpbase.cxx
index b2dc2711dc93..aeecd54a85c3 100644
--- a/cui/source/dialogs/hltpbase.cxx
+++ b/cui/source/dialogs/hltpbase.cxx
@@ -74,7 +74,7 @@ OUString CreateUiNameFromURL( const OUString& aStrURL )
 
 // ComboBox-Control for URL's with History and Autocompletion
 SvxHyperURLBox::SvxHyperURLBox(std::unique_ptr<weld::ComboBox> xControl)
-    : URLBox(std::move(xControl))
+    : SvtURLBox(std::move(xControl))
     , DropTargetHelper(getWidget()->get_drop_target())
 {
     SetSmartProtocol(INetProtocol::Http);
diff --git a/cui/source/inc/hltpbase.hxx b/cui/source/inc/hltpbase.hxx
index 278eab3dd853..0860fff0e2fc 100644
--- a/cui/source/inc/hltpbase.hxx
+++ b/cui/source/inc/hltpbase.hxx
@@ -33,7 +33,7 @@
 #include "iconcdlg.hxx"
 
 /// ComboBox-Control for URL's with History and Autocompletion
-class SvxHyperURLBox : public URLBox, public DropTargetHelper
+class SvxHyperURLBox : public SvtURLBox, public DropTargetHelper
 {
 protected:
     virtual sal_Int8    AcceptDrop( const AcceptDropEvent& rEvt ) override;
diff --git a/cui/source/options/doclinkdialog.cxx b/cui/source/options/doclinkdialog.cxx
index 1baf362e778b..4218a18a1a04 100644
--- a/cui/source/options/doclinkdialog.cxx
+++ b/cui/source/options/doclinkdialog.cxx
@@ -44,7 +44,7 @@ namespace svx
         , m_xName(m_xBuilder->weld_entry("name"))
         , m_xOK(m_xBuilder->weld_button("ok"))
         , m_xAltTitle(m_xBuilder->weld_label("alttitle"))
-        , m_xURL(new URLBox(m_xBuilder->weld_combo_box("url")))
+        , m_xURL(new SvtURLBox(m_xBuilder->weld_combo_box("url")))
     {
         if (!_bCreateNew)
             m_xDialog->set_title(m_xAltTitle->get_label());
diff --git a/cui/source/options/doclinkdialog.hxx b/cui/source/options/doclinkdialog.hxx
index f9e48f3e57c9..371dc6504fe9 100644
--- a/cui/source/options/doclinkdialog.hxx
+++ b/cui/source/options/doclinkdialog.hxx
@@ -34,7 +34,7 @@ namespace svx
         std::unique_ptr<weld::Entry> m_xName;
         std::unique_ptr<weld::Button> m_xOK;
         std::unique_ptr<weld::Label> m_xAltTitle;
-        std::unique_ptr<URLBox> m_xURL;
+        std::unique_ptr<SvtURLBox> m_xURL;
 
     public:
         ODocumentLinkDialog(weld::Window* pParent, bool bCreateNew);
diff --git a/extensions/source/abpilot/abpfinalpage.cxx b/extensions/source/abpilot/abpfinalpage.cxx
index 685592f8c739..388568c12651 100644
--- a/extensions/source/abpilot/abpfinalpage.cxx
+++ b/extensions/source/abpilot/abpfinalpage.cxx
@@ -45,7 +45,7 @@ namespace abp
     FinalPage::FinalPage(weld::Container* pPage, OAddressBookSourcePilot* pWizard)
         : AddressBookSourcePage(pPage, pWizard, "modules/sabpilot/ui/datasourcepage.ui",
                                 "DataSourcePage")
-        , m_xLocation(new URLBox(m_xBuilder->weld_combo_box("location")))
+        , m_xLocation(new SvtURLBox(m_xBuilder->weld_combo_box("location")))
         , m_xBrowse(m_xBuilder->weld_button("browse"))
         , m_xRegisterName(m_xBuilder->weld_check_button("available"))
         , m_xEmbed(m_xBuilder->weld_check_button("embed"))
diff --git a/extensions/source/abpilot/abpfinalpage.hxx b/extensions/source/abpilot/abpfinalpage.hxx
index c4cc6bccf6c0..d82143c15091 100644
--- a/extensions/source/abpilot/abpfinalpage.hxx
+++ b/extensions/source/abpilot/abpfinalpage.hxx
@@ -31,7 +31,7 @@ namespace abp
 
     class FinalPage final : public AddressBookSourcePage
     {
-        std::unique_ptr<URLBox> m_xLocation;
+        std::unique_ptr<SvtURLBox> m_xLocation;
         std::unique_ptr<weld::Button> m_xBrowse;
         std::unique_ptr<weld::CheckButton> m_xRegisterName;
         std::unique_ptr<weld::CheckButton> m_xEmbed;
diff --git a/extensions/source/propctrlr/formcomponenthandler.cxx b/extensions/source/propctrlr/formcomponenthandler.cxx
index 9b66c241c6af..291f50203930 100644
--- a/extensions/source/propctrlr/formcomponenthandler.cxx
+++ b/extensions/source/propctrlr/formcomponenthandler.cxx
@@ -998,7 +998,7 @@ namespace pcr
         case PROPERTY_ID_IMAGE_URL:
         {
             std::unique_ptr<weld::Builder> xBuilder(PropertyHandlerHelper::makeBuilder("modules/spropctrlr/ui/urlcontrol.ui", m_xContext));
-            auto pControl = new OFileUrlControl(std::make_unique<URLBox>(xBuilder->weld_combo_box("urlcontrol")), std::move(xBuilder), false);
+            auto pControl = new OFileUrlControl(std::make_unique<SvtURLBox>(xBuilder->weld_combo_box("urlcontrol")), std::move(xBuilder), false);
             pControl->SetModifyHandler();
             aDescriptor.Control = pControl;
 
diff --git a/extensions/source/propctrlr/usercontrol.cxx b/extensions/source/propctrlr/usercontrol.cxx
index 60378dafd0df..b2d2a5384310 100644
--- a/extensions/source/propctrlr/usercontrol.cxx
+++ b/extensions/source/propctrlr/usercontrol.cxx
@@ -220,7 +220,7 @@ namespace pcr
     }
 
     //= OFileUrlControl
-    OFileUrlControl::OFileUrlControl(std::unique_ptr<URLBox> xWidget, std::unique_ptr<weld::Builder> xBuilder, bool bReadOnly)
+    OFileUrlControl::OFileUrlControl(std::unique_ptr<SvtURLBox> xWidget, std::unique_ptr<weld::Builder> xBuilder, bool bReadOnly)
         : OFileUrlControl_Base(PropertyControlType::Unknown, std::move(xBuilder), std::move(xWidget), bReadOnly)
     {
         getTypedControlWindow()->DisableHistory();
diff --git a/extensions/source/propctrlr/usercontrol.hxx b/extensions/source/propctrlr/usercontrol.hxx
index 3283a6f56f96..b95f9b663be0 100644
--- a/extensions/source/propctrlr/usercontrol.hxx
+++ b/extensions/source/propctrlr/usercontrol.hxx
@@ -115,11 +115,11 @@ namespace pcr
     };
 
     //= OFileUrlControl
-    typedef CommonBehaviourControl<css::inspection::XPropertyControl, URLBox> OFileUrlControl_Base;
+    typedef CommonBehaviourControl<css::inspection::XPropertyControl, SvtURLBox> OFileUrlControl_Base;
     class OFileUrlControl : public OFileUrlControl_Base
     {
     public:
-        OFileUrlControl(std::unique_ptr<URLBox> xWidget, std::unique_ptr<weld::Builder> xBuilder, bool bReadOnly);
+        OFileUrlControl(std::unique_ptr<SvtURLBox> xWidget, std::unique_ptr<weld::Builder> xBuilder, bool bReadOnly);
 
         // XPropertyControl
         virtual css::uno::Any SAL_CALL getValue() override;
diff --git a/filter/source/xsltdialog/xmlfiltertabpagexslt.cxx b/filter/source/xsltdialog/xmlfiltertabpagexslt.cxx
index 8f3e288a1f69..4d758da28f49 100644
--- a/filter/source/xsltdialog/xmlfiltertabpagexslt.cxx
+++ b/filter/source/xsltdialog/xmlfiltertabpagexslt.cxx
@@ -36,11 +36,11 @@ XMLFilterTabPageXSLT::XMLFilterTabPageXSLT(weld::Widget* pPage, weld::Dialog* pD
     , m_xBuilder(Application::CreateBuilder(pPage, "filter/ui/xmlfiltertabpagetransformation.ui"))
     , m_xContainer(m_xBuilder->weld_widget("XmlFilterTabPageTransformation"))
     , m_xEDDocType(m_xBuilder->weld_entry("doc"))
-    , m_xEDExportXSLT(new URLBox(m_xBuilder->weld_combo_box("xsltexport")))
+    , m_xEDExportXSLT(new SvtURLBox(m_xBuilder->weld_combo_box("xsltexport")))
     , m_xPBExprotXSLT(m_xBuilder->weld_button("browseexport"))
-    , m_xEDImportXSLT(new URLBox(m_xBuilder->weld_combo_box("xsltimport")))
+    , m_xEDImportXSLT(new SvtURLBox(m_xBuilder->weld_combo_box("xsltimport")))
     , m_xPBImportXSLT(m_xBuilder->weld_button("browseimport"))
-    , m_xEDImportTemplate(new URLBox(m_xBuilder->weld_combo_box("tempimport")))
+    , m_xEDImportTemplate(new SvtURLBox(m_xBuilder->weld_combo_box("tempimport")))
     , m_xPBImportTemplate(m_xBuilder->weld_button("browsetemp"))
     , m_xCBNeedsXSLT2(m_xBuilder->weld_check_button("filtercb"))
 {
@@ -81,7 +81,7 @@ void XMLFilterTabPageXSLT::SetInfo(const filter_info_impl* pInfo)
     }
 }
 
-void XMLFilterTabPageXSLT::SetURL( URLBox& rURLBox, const OUString& rURL )
+void XMLFilterTabPageXSLT::SetURL( SvtURLBox& rURLBox, const OUString& rURL )
 {
     OUString aPath;
 
@@ -114,7 +114,7 @@ void XMLFilterTabPageXSLT::SetURL( URLBox& rURLBox, const OUString& rURL )
     }
 }
 
-OUString XMLFilterTabPageXSLT::GetURL(const URLBox& rURLBox)
+OUString XMLFilterTabPageXSLT::GetURL(const SvtURLBox& rURLBox)
 {
     OUString aURL;
     OUString aStrPath(rURLBox.get_active_text());
@@ -134,7 +134,7 @@ OUString XMLFilterTabPageXSLT::GetURL(const URLBox& rURLBox)
 
 IMPL_LINK ( XMLFilterTabPageXSLT, ClickBrowseHdl_Impl, weld::Button&, rButton, void )
 {
-    URLBox* pURLBox;
+    SvtURLBox* pURLBox;
 
     if( &rButton == m_xPBExprotXSLT.get() )
     {
diff --git a/filter/source/xsltdialog/xmlfiltertabpagexslt.hxx b/filter/source/xsltdialog/xmlfiltertabpagexslt.hxx
index 3d048f070178..142c27a119f2 100644
--- a/filter/source/xsltdialog/xmlfiltertabpagexslt.hxx
+++ b/filter/source/xsltdialog/xmlfiltertabpagexslt.hxx
@@ -28,8 +28,8 @@ class filter_info_impl;
 class XMLFilterTabPageXSLT
 {
 private:
-    void SetURL(URLBox& rURLBox, const OUString& rURL);
-    static OUString GetURL(const URLBox& rURLBox);
+    void SetURL(SvtURLBox& rURLBox, const OUString& rURL);
+    static OUString GetURL(const SvtURLBox& rURLBox);
 
     OUString sInstPath;
 
@@ -46,11 +46,11 @@ public:
     std::unique_ptr<weld::Builder> m_xBuilder;
     std::unique_ptr<weld::Widget>  m_xContainer;
     std::unique_ptr<weld::Entry>   m_xEDDocType;
-    std::unique_ptr<URLBox>        m_xEDExportXSLT;
+    std::unique_ptr<SvtURLBox>     m_xEDExportXSLT;
     std::unique_ptr<weld::Button>  m_xPBExprotXSLT;
-    std::unique_ptr<URLBox>        m_xEDImportXSLT;
+    std::unique_ptr<SvtURLBox>     m_xEDImportXSLT;
     std::unique_ptr<weld::Button>  m_xPBImportXSLT;
-    std::unique_ptr<URLBox>        m_xEDImportTemplate;
+    std::unique_ptr<SvtURLBox>     m_xEDImportTemplate;
     std::unique_ptr<weld::Button>  m_xPBImportTemplate;
     std::unique_ptr<weld::CheckButton> m_xCBNeedsXSLT2;
 };
diff --git a/fpicker/source/office/iodlg.cxx b/fpicker/source/office/iodlg.cxx
index 60dd893b34ae..e8f50f6d15d4 100644
--- a/fpicker/source/office/iodlg.cxx
+++ b/fpicker/source/office/iodlg.cxx
@@ -292,10 +292,10 @@ SvtFileDialog::SvtFileDialog(weld::Window* pParent, PickerFlags nStyle)
 {
     m_xImpl->m_xCbOptions = m_xBuilder->weld_check_button("options");
     m_xImpl->m_xFtFileName = m_xBuilder->weld_label("file_name_label");
-    m_xImpl->m_xEdFileName.reset(new URLBox(m_xBuilder->weld_combo_box("file_name")));
+    m_xImpl->m_xEdFileName.reset(new SvtURLBox(m_xBuilder->weld_combo_box("file_name")));
     m_xImpl->m_xFtFileType = m_xBuilder->weld_label("file_type_label");
     m_xImpl->m_xLbFilter = m_xBuilder->weld_combo_box("file_type");
-    m_xImpl->m_xEdCurrentPath.reset(new URLBox(m_xBuilder->weld_combo_box("current_path")));
+    m_xImpl->m_xEdCurrentPath.reset(new SvtURLBox(m_xBuilder->weld_combo_box("current_path")));
     m_xImpl->m_xBtnFileOpen = m_xBuilder->weld_button("open");
     m_xImpl->m_xBtnCancel = m_xBuilder->weld_button("cancel");
     m_xImpl->m_xBtnHelp = m_xBuilder->weld_button("help");
@@ -713,7 +713,7 @@ void SvtFileDialog::OpenHdl_Impl(void const * pVoid)
         INetURLObject aFileObject( aFileName );
         if ( ( aFileObject.GetProtocol() == INetProtocol::NotValid ) && !aFileName.isEmpty() )
         {
-            OUString sCompleted = URLBox::ParseSmart( aFileName, m_xFileView->GetViewURL() );
+            OUString sCompleted = SvtURLBox::ParseSmart( aFileName, m_xFileView->GetViewURL() );
             if ( !sCompleted.isEmpty() )
                 aFileName = sCompleted;
         }
diff --git a/fpicker/source/office/iodlg.hxx b/fpicker/source/office/iodlg.hxx
index 2dc3df9ec9e5..fbca0a7711af 100644
--- a/fpicker/source/office/iodlg.hxx
+++ b/fpicker/source/office/iodlg.hxx
@@ -38,7 +38,7 @@
 class SvtFileView;
 class SvtFileDialogFilter_Impl;
 class SvtExpFileDlg_Impl;
-class URLBox;
+class SvtURLBox;
 
 enum class AdjustFilterFlags {
     NONE            = 0x0000,
diff --git a/fpicker/source/office/iodlgimp.hxx b/fpicker/source/office/iodlgimp.hxx
index 27e2731fd29a..2b200f466a7b 100644
--- a/fpicker/source/office/iodlgimp.hxx
+++ b/fpicker/source/office/iodlgimp.hxx
@@ -100,7 +100,7 @@ private:
     DECL_LINK(ClickHdl, const OString&, void);
 };
 
-class URLBox;
+class SvtURLBox;
 class SvtExpFileDlg_Impl
 {
 private:
@@ -114,7 +114,7 @@ public:
     std::unique_ptr<SvtFileDialogFilter_Impl> m_xUserFilter;
 
     std::unique_ptr<weld::Label> m_xFtFileName;
-    std::unique_ptr<URLBox> m_xEdFileName;
+    std::unique_ptr<SvtURLBox> m_xEdFileName;
 
     std::unique_ptr<weld::Label> m_xFtFileVersion;
     std::unique_ptr<weld::ComboBox> m_xLbFileVersion;
@@ -137,7 +137,7 @@ public:
     std::unique_ptr<weld::Button> m_xBtnNewFolder;
     std::unique_ptr<weld::CheckButton> m_xCbPassword;
     std::unique_ptr<weld::CheckButton> m_xCbGPGEncrypt;
-    std::unique_ptr<URLBox> m_xEdCurrentPath;
+    std::unique_ptr<SvtURLBox> m_xEdCurrentPath;
     std::unique_ptr<weld::CheckButton> m_xCbAutoExtension;
     std::unique_ptr<weld::CheckButton> m_xCbOptions;
 
diff --git a/include/svtools/inettbc.hxx b/include/svtools/inettbc.hxx
index 08893b3e977d..57439cf3ebac 100644
--- a/include/svtools/inettbc.hxx
+++ b/include/svtools/inettbc.hxx
@@ -28,19 +28,18 @@
 #include <vcl/idle.hxx>
 #include <vcl/weld.hxx>
 
-class MatchContext_Impl;
 class SvtMatchContext_Impl;
 class SvtURLBox_Impl;
 
-class SVT_DLLPUBLIC URLBox
+class SVT_DLLPUBLIC SvtURLBox
 {
-    friend class MatchContext_Impl;
+    friend class SvtMatchContext_Impl;
     friend class SvtURLBox_Impl;
 
     Idle                            aChangedIdle;
     OUString                        aBaseURL;
     OUString                        aPlaceHolder;
-    rtl::Reference< MatchContext_Impl > pCtx;
+    rtl::Reference<SvtMatchContext_Impl> pCtx;
     std::unique_ptr<SvtURLBox_Impl> pImpl;
     INetProtocol                    eSmartProtocol;
     bool                            bOnlyDirectories    : 1;
@@ -61,8 +60,8 @@ class SVT_DLLPUBLIC URLBox
     SVT_DLLPRIVATE void             Init();
 
 public:
-    URLBox(std::unique_ptr<weld::ComboBox> xWidget);
-    ~URLBox();
+    SvtURLBox(std::unique_ptr<weld::ComboBox> xWidget);
+    ~SvtURLBox();
 
     void                set_entry_text(const OUString& rStr) { m_xWidget->set_entry_text(rStr); }
     void                show() { m_xWidget->show(); }
diff --git a/include/svx/databaselocationinput.hxx b/include/svx/databaselocationinput.hxx
index ae0cd05e0484..edc186b89812 100644
--- a/include/svx/databaselocationinput.hxx
+++ b/include/svx/databaselocationinput.hxx
@@ -25,9 +25,7 @@
 
 #include <memory>
 
-class PushButton;
-
-class URLBox;
+class SvtURLBox;
 namespace weld { class Button; class Window; }
 namespace com::sun::star::uno { class XComponentContext; }
 namespace com::sun::star::uno { template <typename > class Reference; }
@@ -49,7 +47,7 @@ namespace svx
     public:
         DatabaseLocationInputController(
             const css::uno::Reference<css::uno::XComponentContext>& _rContext,
-            URLBox& _rLocationInput,
+            SvtURLBox& _rLocationInput,
             weld::Button& _rBrowseButton,
             weld::Window& _rDialog
         );
diff --git a/include/svx/imapdlg.hxx b/include/svx/imapdlg.hxx
index 503cec1e072a..74b5a69a005f 100644
--- a/include/svx/imapdlg.hxx
+++ b/include/svx/imapdlg.hxx
@@ -38,7 +38,7 @@ namespace weld { class Widget; }
 namespace weld { class Window; }
 
 class ImageMap;
-class URLBox;
+class SvtURLBox;
 
 /*************************************************************************
 |*
@@ -93,7 +93,7 @@ class SVX_DLLPUBLIC SvxIMapDlg : public SfxModelessDialogController
     std::unique_ptr<IMapWindow> m_xIMapWnd;
     std::unique_ptr<weld::Toolbar> m_xTbxIMapDlg1;
     std::unique_ptr<weld::Label> m_xFtURL;
-    std::unique_ptr<URLBox> m_xURLBox;
+    std::unique_ptr<SvtURLBox> m_xURLBox;
     std::unique_ptr<weld::Label> m_xFtText;
     std::unique_ptr<weld::Entry> m_xEdtText;
     std::unique_ptr<weld::Label> m_xFtTarget;
diff --git a/sc/source/ui/inc/datastreamdlg.hxx b/sc/source/ui/inc/datastreamdlg.hxx
index 728ab5fcbdc4..db9fe01b0620 100644
--- a/sc/source/ui/inc/datastreamdlg.hxx
+++ b/sc/source/ui/inc/datastreamdlg.hxx
@@ -15,7 +15,7 @@
 #include <vcl/weld.hxx>
 
 class ScDocShell;
-class URLBox;
+class SvtURLBox;
 class ScRange;
 
 namespace sc {
@@ -26,7 +26,7 @@ class DataStreamDlg : public weld::GenericDialogController
 {
     ScDocShell *m_pDocShell;
 
-    std::unique_ptr<URLBox> m_xCbUrl;
+    std::unique_ptr<SvtURLBox> m_xCbUrl;
     std::unique_ptr<weld::Button> m_xBtnBrowse;
     std::unique_ptr<weld::RadioButton> m_xRBValuesInLine;
     std::unique_ptr<weld::RadioButton> m_xRBAddressValue;
diff --git a/sc/source/ui/inc/linkarea.hxx b/sc/source/ui/inc/linkarea.hxx
index 082ef439c3f3..85cf87f06c29 100644
--- a/sc/source/ui/inc/linkarea.hxx
+++ b/sc/source/ui/inc/linkarea.hxx
@@ -28,7 +28,7 @@ namespace sfx2 { class DocumentInserter; }
 namespace sfx2 { class FileDialogHelper; }
 
 class ScDocShell;
-class URLBox;
+class SvtURLBox;
 
 class ScLinkedAreaDlg : public weld::GenericDialogController
 {
@@ -37,7 +37,7 @@ private:
     std::unique_ptr<sfx2::DocumentInserter> m_xDocInserter;
     SfxObjectShellRef   aSourceRef;
 
-    std::unique_ptr<URLBox> m_xCbUrl;
+    std::unique_ptr<SvtURLBox> m_xCbUrl;
     std::unique_ptr<weld::Button> m_xBtnBrowse;
     std::unique_ptr<weld::TreeView> m_xLbRanges;
     std::unique_ptr<weld::CheckButton> m_xBtnReload;
diff --git a/sc/source/ui/miscdlgs/datastreamdlg.cxx b/sc/source/ui/miscdlgs/datastreamdlg.cxx
index 672e04d5af70..bdc42cdd5be8 100644
--- a/sc/source/ui/miscdlgs/datastreamdlg.cxx
+++ b/sc/source/ui/miscdlgs/datastreamdlg.cxx
@@ -20,7 +20,7 @@ namespace sc {
 DataStreamDlg::DataStreamDlg(ScDocShell *pDocShell, weld::Window* pParent)
     : GenericDialogController(pParent, "modules/scalc/ui/datastreams.ui", "DataStreamDialog")
     , m_pDocShell(pDocShell)
-    , m_xCbUrl(new URLBox(m_xBuilder->weld_combo_box("url")))
+    , m_xCbUrl(new SvtURLBox(m_xBuilder->weld_combo_box("url")))
     , m_xBtnBrowse(m_xBuilder->weld_button("browse"))
     , m_xRBValuesInLine(m_xBuilder->weld_radio_button("valuesinline"))
     , m_xRBAddressValue(m_xBuilder->weld_radio_button("addressvalue"))
diff --git a/sc/source/ui/miscdlgs/linkarea.cxx b/sc/source/ui/miscdlgs/linkarea.cxx
index bd4307c5cf78..ee7d738597dd 100644
--- a/sc/source/ui/miscdlgs/linkarea.cxx
+++ b/sc/source/ui/miscdlgs/linkarea.cxx
@@ -38,7 +38,7 @@
 ScLinkedAreaDlg::ScLinkedAreaDlg(weld::Window* pParent)
     : GenericDialogController(pParent, "modules/scalc/ui/externaldata.ui", "ExternalDataDialog")
     , m_pSourceShell(nullptr)
-    , m_xCbUrl(new URLBox(m_xBuilder->weld_combo_box("url")))
+    , m_xCbUrl(new SvtURLBox(m_xBuilder->weld_combo_box("url")))
     , m_xBtnBrowse(m_xBuilder->weld_button("browse"))
     , m_xLbRanges(m_xBuilder->weld_tree_view("ranges"))
     , m_xBtnReload(m_xBuilder->weld_check_button("reload"))
diff --git a/sfx2/inc/inettbc.hxx b/sfx2/inc/inettbc.hxx
index d9c8f52a31c4..6427565ceef9 100644
--- a/sfx2/inc/inettbc.hxx
+++ b/sfx2/inc/inettbc.hxx
@@ -25,14 +25,14 @@
 
 namespace weld { class ComboBox; };
 class URLBoxItemWindow;
-class URLBox;
+class SvtURLBox;
 
 class SfxURLToolBoxControl_Impl final : public SfxToolBoxControl
 {
 private:
     bool                    m_bModified;
 
-    URLBox*                 GetURLBox() const;
+    SvtURLBox*              GetURLBox() const;
     URLBoxItemWindow*       GetURLBoxItemWindow() const;
     void                    OpenURL( const OUString& rName ) const;
 
diff --git a/sfx2/source/inet/inettbc.cxx b/sfx2/source/inet/inettbc.cxx
index 5d9767f0b198..4c0780b0f82a 100644
--- a/sfx2/source/inet/inettbc.cxx
+++ b/sfx2/source/inet/inettbc.cxx
@@ -63,20 +63,20 @@ SfxURLToolBoxControl_Impl::~SfxURLToolBoxControl_Impl()
 class URLBoxItemWindow final : public InterimItemWindow
 {
 private:
-    std::unique_ptr<URLBox> m_xWidget;
+    std::unique_ptr<SvtURLBox> m_xWidget;
 
     DECL_LINK(KeyInputHdl, const KeyEvent&, bool);
 public:
     URLBoxItemWindow(vcl::Window* pParent)
         : InterimItemWindow(pParent, "sfx/ui/urlbox.ui", "URLBox")
-        , m_xWidget(new URLBox(m_xBuilder->weld_combo_box("urlbox")))
+        , m_xWidget(new SvtURLBox(m_xBuilder->weld_combo_box("urlbox")))
     {
         m_xWidget->connect_key_press(LINK(this, URLBoxItemWindow, KeyInputHdl));
 
         SetSizePixel(m_xWidget->get_preferred_size());
     }
 
-    URLBox* GetURLBox()
+    SvtURLBox* GetURLBox()
     {
         return m_xWidget.get();
     }
@@ -114,7 +114,7 @@ URLBoxItemWindow* SfxURLToolBoxControl_Impl::GetURLBoxItemWindow() const
     return static_cast<URLBoxItemWindow*>(GetToolBox().GetItemWindow(GetId()));
 }
 
-URLBox* SfxURLToolBoxControl_Impl::GetURLBox() const
+SvtURLBox* SfxURLToolBoxControl_Impl::GetURLBox() const
 {
     return GetURLBoxItemWindow()->GetURLBox();
 }
@@ -127,7 +127,7 @@ void SfxURLToolBoxControl_Impl::OpenURL( const OUString& rName ) const
     INetURLObject aObj( rName );
     if ( aObj.GetProtocol() == INetProtocol::NotValid )
     {
-        aName = URLBox::ParseSmart( rName, "" );
+        aName = SvtURLBox::ParseSmart( rName, "" );
     }
     else
         aName = rName;
@@ -190,7 +190,7 @@ IMPL_STATIC_LINK( SfxURLToolBoxControl_Impl, ExecuteHdl_Impl, void*, p, void )
 VclPtr<vcl::Window> SfxURLToolBoxControl_Impl::CreateItemWindow( vcl::Window* pParent )
 {
     VclPtrInstance<URLBoxItemWindow> xURLBox(pParent);
-    URLBox* pURLBox = xURLBox->GetURLBox();
+    SvtURLBox* pURLBox = xURLBox->GetURLBox();
     pURLBox->connect_changed(LINK(this, SfxURLToolBoxControl_Impl, SelectHdl));
     pURLBox->connect_entry_activate(LINK(this, SfxURLToolBoxControl_Impl, OpenHdl));
     return xURLBox;
@@ -200,7 +200,7 @@ IMPL_LINK(SfxURLToolBoxControl_Impl, SelectHdl, weld::ComboBox&, rComboBox, void
 {
     m_bModified = true;
 
-    URLBox* pURLBox = GetURLBox();
+    SvtURLBox* pURLBox = GetURLBox();
     OUString aName( pURLBox->GetURL() );
 
     if (rComboBox.changed_by_menu() && !aName.isEmpty())
@@ -209,7 +209,7 @@ IMPL_LINK(SfxURLToolBoxControl_Impl, SelectHdl, weld::ComboBox&, rComboBox, void
 
 IMPL_LINK_NOARG(SfxURLToolBoxControl_Impl, OpenHdl, weld::ComboBox&, bool)
 {
-    URLBox* pURLBox = GetURLBox();
+    SvtURLBox* pURLBox = GetURLBox();
     OpenURL( pURLBox->GetURL() );
 
     Reference< XDesktop2 > xDesktop = Desktop::create( m_xContext );
@@ -250,7 +250,7 @@ void SfxURLToolBoxControl_Impl::StateChanged
     }
     else if ( !m_bModified && SfxItemState::DEFAULT == eState )
     {
-        URLBox* pURLBox = GetURLBox();
+        SvtURLBox* pURLBox = GetURLBox();
         pURLBox->clear();
 
         const css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > > lList = SvtHistoryOptions().GetList(ePICKLIST);
diff --git a/svx/source/dialog/imapdlg.cxx b/svx/source/dialog/imapdlg.cxx
index d7a5e130cfe1..e015b3716351 100644
--- a/svx/source/dialog/imapdlg.cxx
+++ b/svx/source/dialog/imapdlg.cxx
@@ -106,7 +106,7 @@ SvxIMapDlg::SvxIMapDlg(SfxBindings *_pBindings, SfxChildWindow *pCW, weld::Windo
     , m_xIMapWnd(new IMapWindow(_pBindings->GetActiveFrame(), m_xDialog.get()))
     , m_xTbxIMapDlg1(m_xBuilder->weld_toolbar("toolbar"))
     , m_xFtURL(m_xBuilder->weld_label("urlft"))
-    , m_xURLBox(new URLBox(m_xBuilder->weld_combo_box("url")))
+    , m_xURLBox(new SvtURLBox(m_xBuilder->weld_combo_box("url")))
     , m_xFtText(m_xBuilder->weld_label("textft"))
     , m_xEdtText(m_xBuilder->weld_entry("text"))
     , m_xFtTarget(m_xBuilder->weld_label("targetft"))
diff --git a/svx/source/form/databaselocationinput.cxx b/svx/source/form/databaselocationinput.cxx
index 4688d1cab7af..3e28e2154d40 100644
--- a/svx/source/form/databaselocationinput.cxx
+++ b/svx/source/form/databaselocationinput.cxx
@@ -54,7 +54,7 @@ namespace svx
     public:
         DatabaseLocationInputController_Impl(
             const Reference<XComponentContext>&     _rContext,
-            URLBox& _rLocationInput,
+            SvtURLBox& _rLocationInput,
             weld::Button& _rBrowseButton,
             weld::Window& _rDialog
         );
@@ -72,7 +72,7 @@ namespace svx
 
     private:
         const Reference<XComponentContext>      m_xContext;
-        URLBox& m_rLocationInput;
+        SvtURLBox& m_rLocationInput;
         weld::Window& m_rDialog;
         Sequence< OUString >             m_aFilterExtensions;
         OUString                         m_sFilterUIName;
@@ -80,7 +80,7 @@ namespace svx
     };
 
     DatabaseLocationInputController_Impl::DatabaseLocationInputController_Impl(const Reference<XComponentContext>& _rContext,
-            URLBox& _rLocationInput, weld::Button& _rBrowseButton, weld::Window& _rDialog)
+            SvtURLBox& _rLocationInput, weld::Button& _rBrowseButton, weld::Window& _rDialog)
         :m_xContext( _rContext )
         ,m_rLocationInput( _rLocationInput )
         ,m_rDialog( _rDialog )
@@ -221,7 +221,7 @@ namespace svx
     }
 
     DatabaseLocationInputController::DatabaseLocationInputController( const Reference<XComponentContext>& _rContext,
-            URLBox& _rLocationInput, weld::Button& _rBrowseButton, weld::Window& _rDialog )
+            SvtURLBox& _rLocationInput, weld::Button& _rBrowseButton, weld::Window& _rDialog )
         :m_pImpl( new DatabaseLocationInputController_Impl( _rContext, _rLocationInput, _rBrowseButton, _rDialog ) )
     {
     }
diff --git a/svx/source/form/datanavi.cxx b/svx/source/form/datanavi.cxx
index 657d22ab289c..92cfa4e26707 100644
--- a/svx/source/form/datanavi.cxx
+++ b/svx/source/form/datanavi.cxx
@@ -3191,7 +3191,7 @@ namespace svxform
         : GenericDialogController(pParent, "svx/ui/addinstancedialog.ui", "AddInstanceDialog")
         , m_xNameED(m_xBuilder->weld_entry("name"))
         , m_xURLFT(m_xBuilder->weld_label("urlft"))
-        , m_xURLED(new URLBox(m_xBuilder->weld_combo_box("url")))
+        , m_xURLED(new SvtURLBox(m_xBuilder->weld_combo_box("url")))
         , m_xFilePickerBtn(m_xBuilder->weld_button("browse"))
         , m_xLinkInstanceCB(m_xBuilder->weld_check_button("link"))
         , m_xAltTitle(m_xBuilder->weld_label("alttitle"))
diff --git a/svx/source/inc/datanavi.hxx b/svx/source/inc/datanavi.hxx
index 78bc126fea86..a948c5e9190b 100644
--- a/svx/source/inc/datanavi.hxx
+++ b/svx/source/inc/datanavi.hxx
@@ -584,7 +584,7 @@ namespace svxform
 
         std::unique_ptr<weld::Entry> m_xNameED;
         std::unique_ptr<weld::Label> m_xURLFT;
-        std::unique_ptr<URLBox> m_xURLED;
+        std::unique_ptr<SvtURLBox> m_xURLED;
         std::unique_ptr<weld::Button> m_xFilePickerBtn;
         std::unique_ptr<weld::CheckButton> m_xLinkInstanceCB;
         std::unique_ptr<weld::Label> m_xAltTitle;


More information about the Libreoffice-commits mailing list
diff --git a/svtools/source/control/inettbc.cxx b/svtools/source/control/inettbc.cxx
index 6c80553014e1..5a7fc9c0c850 100644
--- a/svtools/source/control/inettbc.cxx
+++ b/svtools/source/control/inettbc.cxx
@@ -82,7 +82,7 @@ public:
     }
 };
 
-class MatchContext_Impl: public salhelper::Thread
+class SvtMatchContext_Impl: public salhelper::Thread
 {
     static ::osl::Mutex*            pDirMutex;
 
@@ -91,7 +91,7 @@ class MatchContext_Impl: public salhelper::Thread
     std::vector<OUString>           aURLs;
     svtools::AsynchronLink          aLink;
     OUString const                  aText;
-    URLBox*                         pBox;
+    SvtURLBox*                      pBox;
     bool const                      bOnlyDirectories;
     bool const                      bNoSelection;
 
@@ -102,7 +102,7 @@ class MatchContext_Impl: public salhelper::Thread
 
     DECL_LINK(                Select_Impl, void*, void );
 
-    virtual                         ~MatchContext_Impl() override;
+    virtual                         ~SvtMatchContext_Impl() override;
     virtual void                    execute() override;
     void                            doExecute();
     void                            Insert( const OUString& rCompletion, const OUString& rURL, bool bForce = false);
@@ -110,7 +110,7 @@ class MatchContext_Impl: public salhelper::Thread
     static void                     FillPicklist(std::vector<OUString>& rPickList);
 
 public:
-                                    MatchContext_Impl( URLBox* pBoxP, const OUString& rText );
+                                    SvtMatchContext_Impl( SvtURLBox* pBoxP, const OUString& rText );
     void                            Stop();
 };
 
@@ -121,9 +121,9 @@ namespace
         : public rtl::Static< ::osl::Mutex, theSvtMatchContextMutex > {};
 }
 
-MatchContext_Impl::MatchContext_Impl(URLBox* pBoxP, const OUString& rText)
+SvtMatchContext_Impl::SvtMatchContext_Impl(SvtURLBox* pBoxP, const OUString& rText)
     : Thread( "MatchContext_Impl" )
-    , aLink( LINK( this, MatchContext_Impl, Select_Impl ) )
+    , aLink( LINK( this, SvtMatchContext_Impl, Select_Impl ) )
     , aText( rText )
     , pBox( pBoxP )
     , bOnlyDirectories( pBoxP->bOnlyDirectories )
@@ -136,12 +136,12 @@ MatchContext_Impl::MatchContext_Impl(URLBox* pBoxP, const OUString& rText)
     FillPicklist( aPickList );
 }
 
-MatchContext_Impl::~MatchContext_Impl()
+SvtMatchContext_Impl::~SvtMatchContext_Impl()
 {
     aLink.ClearPendingCall();
 }
 
-void MatchContext_Impl::FillPicklist(std::vector<OUString>& rPickList)
+void SvtMatchContext_Impl::FillPicklist(std::vector<OUString>& rPickList)
 {
     // Read the history of picks
     Sequence< Sequence< PropertyValue > > seqPicklist = SvtHistoryOptions().GetList( ePICKLIST );
@@ -165,7 +165,7 @@ void MatchContext_Impl::FillPicklist(std::vector<OUString>& rPickList)
     }
 }
 
-void MatchContext_Impl::Stop()
+void SvtMatchContext_Impl::Stop()
 {
     css::uno::Reference< css::ucb::XCommandProcessor > proc;
     sal_Int32 id(0);
@@ -183,7 +183,7 @@ void MatchContext_Impl::Stop()
     terminate();
 }
 
-void MatchContext_Impl::execute( )
+void SvtMatchContext_Impl::execute( )
 {
     doExecute();
     aLink.Call( this );
@@ -196,7 +196,7 @@ void MatchContext_Impl::execute( )
 // Cancellable does not discard the information gained so far, it
 // inserts all collected completions into the listbox.
 
-IMPL_LINK_NOARG( MatchContext_Impl, Select_Impl, void*, void )
+IMPL_LINK_NOARG( SvtMatchContext_Impl, Select_Impl, void*, void )
 {
     // avoid recursion through cancel button
     {
@@ -246,7 +246,7 @@ IMPL_LINK_NOARG( MatchContext_Impl, Select_Impl, void*, void )
     pBox->pCtx.clear();
 }
 
-void MatchContext_Impl::Insert( const OUString& rCompletion,
+void SvtMatchContext_Impl::Insert( const OUString& rCompletion,
                                    const OUString& rURL,
                                    bool bForce )
 {
@@ -262,7 +262,7 @@ void MatchContext_Impl::Insert( const OUString& rCompletion,
 }
 
 
-void MatchContext_Impl::ReadFolder( const OUString& rURL,
+void SvtMatchContext_Impl::ReadFolder( const OUString& rURL,
                                        const OUString& rMatch,
                                        bool bSmart )
 {
@@ -424,7 +424,7 @@ void MatchContext_Impl::ReadFolder( const OUString& rURL,
     }
 }
 
-void MatchContext_Impl::doExecute()
+void SvtMatchContext_Impl::doExecute()
 {
     ::osl::MutexGuard aGuard( theSvtMatchContextMutex::get() );
     {
@@ -463,7 +463,7 @@ void MatchContext_Impl::doExecute()
         if( schedule() )
         {
             if ( eProt == INetProtocol::NotValid )
-                aMatch = URLBox::ParseSmart( aText, pBox->aBaseURL );
+                aMatch = SvtURLBox::ParseSmart( aText, pBox->aBaseURL );
             else
                 aMatch = aText;
             if ( !aMatch.isEmpty() )
@@ -472,9 +472,9 @@ void MatchContext_Impl::doExecute()
                 OUString aMainURL( aURLObject.GetMainURL( INetURLObject::DecodeMechanism::NONE ) );
                 // Disable autocompletion for anything but the (local) file
                 // system (for which access is hopefully fast), as the logic of
                 // how MatchContext_Impl is used requires this code to run to
                 // completion before further user input is processed, and even
                 // MatchContext_Impl::Stop does not guarantee a speedy
                 // return:
                 if ( !aMainURL.isEmpty()
                      && aURLObject.GetProtocol() == INetProtocol::File )
@@ -770,7 +770,7 @@ bool SvtURLBox_Impl::TildeParsing(
 
 //--
 
-OUString URLBox::ParseSmart( const OUString& _aText, const OUString& _aBaseURL )
+OUString SvtURLBox::ParseSmart( const OUString& _aText, const OUString& _aBaseURL )
 {
     OUString aMatch;
     OUString aText = _aText;
@@ -849,7 +849,7 @@ OUString URLBox::ParseSmart( const OUString& _aText, const OUString& _aBaseURL )
     return aMatch;
 }
 
-IMPL_LINK_NOARG(URLBox, TryAutoComplete, Timer *, void)
+IMPL_LINK_NOARG(SvtURLBox, TryAutoComplete, Timer *, void)
 {
     OUString aCurText = m_xWidget->get_active_text();
     int nStartPos, nEndPos;
@@ -867,14 +867,14 @@ IMPL_LINK_NOARG(URLBox, TryAutoComplete, Timer *, void)
             pCtx->join();
             pCtx.clear();
         }
-        pCtx = new MatchContext_Impl(this, aCurText);
+        pCtx = new SvtMatchContext_Impl(this, aCurText);
         pCtx->launch();
     }
     else
         m_xWidget->clear();
 }
 
-URLBox::URLBox(std::unique_ptr<weld::ComboBox> pWidget)
+SvtURLBox::SvtURLBox(std::unique_ptr<weld::ComboBox> pWidget)
     : eSmartProtocol(INetProtocol::NotValid)
     , bOnlyDirectories( false )
     , bHistoryDisabled( false )
@@ -887,15 +887,15 @@ URLBox::URLBox(std::unique_ptr<weld::ComboBox> pWidget)
 
     Init();
 
-    m_xWidget->connect_focus_in(LINK(this, URLBox, FocusInHdl));
-    m_xWidget->connect_focus_out(LINK(this, URLBox, FocusOutHdl));
-    m_xWidget->connect_changed(LINK(this, URLBox, ChangedHdl));
+    m_xWidget->connect_focus_in(LINK(this, SvtURLBox, FocusInHdl));
+    m_xWidget->connect_focus_out(LINK(this, SvtURLBox, FocusOutHdl));
+    m_xWidget->connect_changed(LINK(this, SvtURLBox, ChangedHdl));
 
-    aChangedIdle.SetInvokeHandler(LINK(this, URLBox, TryAutoComplete));
+    aChangedIdle.SetInvokeHandler(LINK(this, SvtURLBox, TryAutoComplete));
     aChangedIdle.SetDebugName("svtools::URLBox aChangedIdle");
 }
 
-void URLBox::Init()
+void SvtURLBox::Init()
 {
     pImpl.reset( new SvtURLBox_Impl );
 
@@ -904,7 +904,7 @@ void URLBox::Init()
     UpdatePicklistForSmartProtocol_Impl();
 }
 
-URLBox::~URLBox()
+SvtURLBox::~SvtURLBox()
 {
     if (pCtx.is())
     {
@@ -913,7 +913,7 @@ URLBox::~URLBox()
     }
 }
 
-void URLBox::SetSmartProtocol(INetProtocol eProt)
+void SvtURLBox::SetSmartProtocol(INetProtocol eProt)
 {
     if ( eSmartProtocol != eProt )
     {
@@ -922,7 +922,7 @@ void URLBox::SetSmartProtocol(INetProtocol eProt)
     }
 }
 
-void URLBox::UpdatePicklistForSmartProtocol_Impl()
+void SvtURLBox::UpdatePicklistForSmartProtocol_Impl()
 {
     m_xWidget->clear();
     if ( bHistoryDisabled )
@@ -978,13 +978,13 @@ void URLBox::UpdatePicklistForSmartProtocol_Impl()
     }
 }
 
-IMPL_LINK_NOARG(URLBox, ChangedHdl, weld::ComboBox&, void)
+IMPL_LINK_NOARG(SvtURLBox, ChangedHdl, weld::ComboBox&, void)
 {
     aChangeHdl.Call(*m_xWidget);
     aChangedIdle.Start(); //launch this to happen on idle after cursor position will have been set
 }
 
-IMPL_LINK_NOARG(URLBox, FocusInHdl, weld::Widget&, void)
+IMPL_LINK_NOARG(SvtURLBox, FocusInHdl, weld::Widget&, void)
 {
 #ifndef UNX
     // pb: don't select automatically on unix #93251#
@@ -993,7 +993,7 @@ IMPL_LINK_NOARG(URLBox, FocusInHdl, weld::Widget&, void)
     aFocusInHdl.Call(*m_xWidget);
 }
 
-IMPL_LINK_NOARG(URLBox, FocusOutHdl, weld::Widget&, void)
+IMPL_LINK_NOARG(SvtURLBox, FocusOutHdl, weld::Widget&, void)
 {
     if (pCtx.is())
     {
@@ -1004,19 +1004,19 @@ IMPL_LINK_NOARG(URLBox, FocusOutHdl, weld::Widget&, void)
     aFocusOutHdl.Call(*m_xWidget);
 }
 
-void URLBox::SetOnlyDirectories( bool bDir )
+void SvtURLBox::SetOnlyDirectories( bool bDir )
 {
     bOnlyDirectories = bDir;
     if ( bOnlyDirectories )
         m_xWidget->clear();
 }
 
-void URLBox::SetNoURLSelection( bool bSet )
+void SvtURLBox::SetNoURLSelection( bool bSet )
 {
     bNoSelection = bSet;
 }
 
-OUString URLBox::GetURL()
+OUString SvtURLBox::GetURL()
 {
     // wait for end of autocompletion
     ::osl::MutexGuard aGuard( theSvtMatchContextMutex::get() );
@@ -1094,7 +1094,7 @@ OUString URLBox::GetURL()
     return aObj.GetMainURL( INetURLObject::DecodeMechanism::NONE );
 }
 
-void URLBox::SetBaseURL( const OUString& rURL )
+void SvtURLBox::SetBaseURL( const OUString& rURL )
 {
     ::osl::MutexGuard aGuard( theSvtMatchContextMutex::get() );
 
@@ -1105,13 +1105,13 @@ void URLBox::SetBaseURL( const OUString& rURL )
     aBaseURL = rURL;
 }
 
-void URLBox::DisableHistory()
+void SvtURLBox::DisableHistory()
 {
     bHistoryDisabled = true;
     UpdatePicklistForSmartProtocol_Impl();
 }
 
-void URLBox::SetFilter(const OUString& _sFilter)
+void SvtURLBox::SetFilter(const OUString& _sFilter)
 {
     pImpl->m_aFilters.clear();
     FilterMatch::createWildCardFilterList(_sFilter,pImpl->m_aFilters);
@@ -472,9 +472,9 @@ void MatchContext_Impl::doExecute()
                 // Disable autocompletion for anything but the (local) file
                 // system (for which access is hopefully fast), as the logic of
-                // how MatchContext_Impl is used requires this code to run to
+                // how SvtMatchContext_Impl is used requires this code to run to
                 // completion before further user input is processed, and even
@@ -472,9 +472,9 @@ void MatchContext_Impl::doExecute()
                 // completion before further user input is processed, and even
-                // MatchContext_Impl::Stop does not guarantee a speedy
+                // SvtMatchContext_Impl::Stop does not guarantee a speedy
                 // return:
                 if ( !aMainURL.isEmpty()